{
  description = "System Configuration @ cswimr 2024";
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    cosmic.url = "github:lilyinstarlight/nixos-cosmic";
  };
  outputs =
    {
      self,
      nixpkgs,
      cosmic,
      ...
    }@inputs:
    let
      user = "nixos";
      system = "x86_64-linux";
    in
    {
      nixosConfigurations = {
        nixos = nixpkgs.lib.nixosSystem {
          system = system;
          specialArgs = {
            inherit inputs;
            system = system;
            hostname = "nixos";
            user = user;
          };
          modules = [
            # imports
            ../common.nix
            cosmic.nixosModules.default
            (
              { pkgs, lib, ... }:
              let
                packages = with pkgs; [
                  fastfetch
                  cosmic-wallpapers
                ];
              in
              {
                programs = {
                  firefox.enable = true;
                };

                services = {
                  desktopManager.cosmic.enable = true;
                  displayManager.cosmic-greeter.enable = true;
                };

                virtualisation.vmVariant.virtualisation = {
                  memorySize = 8192;
                  cores = 6;
                };

                environment.systemPackages = lib.lists.unique (packages);

                nix = {
                  settings = {
                    substituters = [
                      "https://cosmic.cachix.org"
                    ];
                    trusted-public-keys = [
                      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
                    ];
                  };
                };
              }
            )
          ];
        };
      };
    };
}
