{
  pkgs,
  stablePkgs,
  config,
  ...
}:
{
  programs.steam = {
    enable = true;
    protontricks.enable = true;
    remotePlay.openFirewall = true; # Open ports in the firewall for Steam Remote Play
    dedicatedServer.openFirewall = true; # Open ports in the firewall for Source Dedicated Server
  };
  programs.gamescope = {
    enable = true;
    capSysNice = true;
    args = [
      "--mangoapp"
      "-w 1080"
      "-h 1920"
    ];
  };
  programs.gamemode = {
    enable = true;
    enableRenice = true;
    settings = {
      general = {
        renice = 10;
        inhibit_screensaver = 1;
      };
      filter = {
        # whitelist = ''
        #   RiseOfTheTombRaider
        # '';

        # blacklist = ''
        #   HalfLife3
        #   glxgears
        # '';
      };
      custom = {
        start = "${pkgs.libnotify}/bin/notify-send 'GameMode started'";
        end = "${pkgs.libnotify}/bin/notify-send 'GameMode ended'";
      };
    };
  };
  environment.systemPackages = with pkgs; [
    (prismlauncher.override {
      jdks = with pkgs; [
        jdk8
        jdk17
        jdk21
      ];
    })
    lunar-client
    stablePkgs.heroic
    dolphin-emu
    ryujinx-greemdev
    protonup-qt
    winetricks
    #(pkgs.callPackage ../packages/lucem.nix { inherit pkgs; })
    vinegar # Roblox Studio, use Sober in ./flatpak.nix for the Roblox Player
    celeste64
  ];

  services.udev.packages = with pkgs; [
    dolphin-emu
  ];

  boot.extraModulePackages = [
    config.boot.kernelPackages.gcadapter-oc-kmod
  ];

  boot.kernelModules = [
    "gcadapter_oc"
  ];
}
