{
  pkgs,
  lib,
  ...
}:
pkgs.stdenv.mkDerivation rec {
  pname = "lucem";
  version = "2.1.2";

  src = pkgs.fetchFromGitHub {
    owner = "xTrayambak";
    repo = "lucem";
    rev = version;
    hash = "sha256-31EdtCQftxhpp2b7fpM5XqRh+r0rBE/k9SpYEPpGpV0=";
  };

  nativeBuildInputs = with pkgs; [
    gtk4.dev
    libadwaita.dev
    pkg-config
    openssl.dev
    curl.dev
    xorg.libX11
    xorg.libXcursor.dev
    xorg.libXrender
    xorg.libXext
    libxkbcommon
    libGL.dev
    wayland.dev
    wayland-protocols
    wayland-scanner.dev
    nimble
  ];

  buildPhase = ''
    runHook preBuild
    nimble build
    runHook postBuild
  '';

  installPhase = ''
    runHook preInstall
    runHook postInstall
  '';

  meta = {
    description = "An open-source bootstrapper for Sober, similar to Bloxstrap.";
    homepage = "https://github.com/xTrayambak/lucem";
    downloadPage = "https://github.com/xTrayambak/lucem/releases/tag/${version}";
    license = lib.licenses.mit; # https://github.com/xTrayambak/lucem/blob/31f996b64edafba1d75e16130bcb14576a326ebd/lucem.nimble#L6
    platforms = lib.platforms.linux;
    maintainers = with lib.maintainers; [ cswimr ];
    mainProgram = "lucem";
  };
}
